'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createStyleSheet = createStyleSheet;
/**
 * styleSheet module. Used to create styleSheet objects.
 *
 * @module styleSheet
 */

/**
 * Core function used to create styleSheet objects
 *
 * @param  {string}   name          - Stylesheet name, should be unique
 * @param  {Function} callback      - Should return the raw rules object, passed
 *                                    `theme` as arg1
 * @param  {Object}   options       - Additional options
 * @return {Object}                 - styleSheet object
 */
function createStyleSheet(name, callback) {
  var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

  var styleSheet = {
    name: name,
    options: options,
    createRules: createRules
  };

  function createRules(theme) {
    if (typeof callback === 'function') {
      return callback(theme);
    }

    return callback;
  }

  return styleSheet;
}